@@ -707,6 +707,21 @@ impl<'a> SyntaxClass<'a> {
             _ => None,
         }
     }
+
+    /// Whether the syntax class or its children contain an error.
+    pub fn erroneous(&self) -> bool {
+        use SyntaxClass::*;
+        match self {
+            Label { .. } => false,
+            VarAccess(cls) => cls.node().erroneous(),
+            Normal(_, node)
+            | Callee(node)
+            | At { node }
+            | Ref { node, .. }
+            | ImportPath(node)
+            | IncludePath(node) => node.erroneous(),
+        }
+    }
 }
 
 /// Classifies node's syntax (inner syntax) that can be operated on by IDE
