@@ -9,7 +9,7 @@ use serde::Deserialize;
 use tinymist_std::time::UtcDateTime;
 pub use typst::diag::PackageError;
 pub use typst::syntax::package::PackageSpec;
-use typst::syntax::package::{PackageInfo, TemplateInfo};
+use typst::syntax::package::{PackageInfo, TemplateInfo, VersionlessPackageSpec};
 
 mod dummy;
 pub use dummy::*;
@@ -30,6 +30,27 @@ pub use http::*;
 /// The default Typst registry.
 pub const DEFAULT_REGISTRY: &str = "https://packages.typst.org";
 
+/// The namespace for Typst registry.
+pub const PREVIEW_NS: &str = "preview";
+
+/// An extension trait for package specifications.
+pub trait PackageSpecExt {
+    /// Returns true if the package spec is in the preview namespace.
+    fn is_preview(&self) -> bool;
+}
+
+impl PackageSpecExt for PackageSpec {
+    fn is_preview(&self) -> bool {
+        self.namespace == PREVIEW_NS
+    }
+}
+
+impl PackageSpecExt for VersionlessPackageSpec {
+    fn is_preview(&self) -> bool {
+        self.namespace == PREVIEW_NS
+    }
+}
+
 /// A trait for package registries.
 pub trait PackageRegistry {
     /// A function to be called when the registry is reset.
@@ -85,6 +106,11 @@ impl PackageIndexEntry {
             version: self.package.version,
         }
     }
+
+    /// Check if this entry matches a versionless package specification.
+    pub fn matches_versionless(&self, spec: &VersionlessPackageSpec) -> bool {
+        self.namespace == spec.namespace && self.package.name == spec.name
+    }
 }
 
 fn deserialize_timestamp<'de, D>(deserializer: D) -> Result<Option<UtcDateTime>, D::Error>
