@@ -8,8 +8,8 @@ use tinymist_std::path::unix_slash;
 
 use crate::Result;
 use crate::common::{
-    CenterNode, ExternalFrameNode, FigureNode, FormatWriter, HighlightNode, InlineNode, ListState,
-    VerbatimNode,
+    BlockVerbatimNode, CenterNode, ExternalFrameNode, FigureNode, FormatWriter, HighlightNode,
+    InlineNode, ListState, VerbatimNode,
 };
 
 /// LaTeX writer implementation
@@ -289,6 +289,11 @@ impl LaTeXWriter {
                     self.write_node(child, output)?;
                 }
             }
+            node if node.is_custom_type::<BlockVerbatimNode>() => {
+                let block_node = node.as_custom_type::<BlockVerbatimNode>().unwrap();
+                output.push_str(&block_node.content);
+                output.push_str("\n\n");
+            }
             node if node.is_custom_type::<VerbatimNode>() => {
                 let inline_node = node.as_custom_type::<VerbatimNode>().unwrap();
                 output.push_str(&inline_node.content);
