@@ -22,7 +22,7 @@ fn test_lsp() {
         });
 
         let hash = replay_log(&root.join("neovim"));
-        insta::assert_snapshot!(hash, @"siphash128_13:276f3fcce1e6b59de00c4308935732ec");
+        insta::assert_snapshot!(hash, @"siphash128_13:f5a120d5d309c539e88e532d99cb843c");
     }
 
     {
@@ -33,7 +33,18 @@ fn test_lsp() {
         });
 
         let hash = replay_log(&root.join("vscode"));
-        insta::assert_snapshot!(hash, @"siphash128_13:9a266bad2c9e8113b66eae3cfe83aab5");
+        insta::assert_snapshot!(hash, @"siphash128_13:bff2030a6c8d2038662fcbb443af583d");
+    }
+
+    {
+        gen_smoke(SmokeArgs {
+            root: root.join("vscode-syntax-only"),
+            init: "initialization/vscode-syntax-only-1.87.2".to_owned(),
+            log: "tests/fixtures/editions/base.log".to_owned(),
+        });
+
+        let hash = replay_log(&root.join("vscode-syntax-only"));
+        insta::assert_snapshot!(hash, @"siphash128_13:bff2030a6c8d2038662fcbb443af583d");
     }
 }
 
